#script to calculate continental temperatures (surface air temperatures over continents), calculated using ssts and surface air temperatures for 1000 years (from yearly snapshots), for vegetation sensitivity
#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Thu Jun 13 14:51:38 2019

@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
from matplotlib.gridspec import GridSpec
from netCDF4 import Dataset
import sys
import numpy.ma as ma

lonlatpsdata=np.loadtxt('ModelOutput_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))


#create grid for maps
lon2d, lat2d = np.meshgrid(lon, lat)

x=lon2d
y=lat2d

nc_f_bare = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_bare/cdo_1000years/snapshots_potsdam2-1000years-yearmean_ts_sst.nc'
nc_f_shrub = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_shrubcover/cdo_1000years/snapshots_potsdam2-1000years-yearmean_ts_sst.nc'
nc_f_tree = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_treecover/cdo_1000years/snapshots_potsdam2-1000years-yearmean_ts_sst.nc'


nc_f_early = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_earlydevveg/cdo_1000years/snapshots_potsdam2-1000years-yearmean_ts_sst.nc'
nc_f_middle = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_middledevveg/cdo_1000years/snapshots_potsdam2-1000years-yearmean_ts_sst.nc'
nc_f_late = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_latedevveg/cdo_1000years/snapshots_potsdam2-1000years-yearmean_ts_sst.nc'



data_bare=Dataset(nc_f_bare, 'r')
ts_bare =data_bare.variables['ts'][0:1000,:,:]
ts_bare=np.mean(ts_bare,axis=0)

data_bare=Dataset(nc_f_bare, 'r')
sst_bare =data_bare.variables['sst'][0:1000,:,:]
sst_bare=np.mean(sst_bare,axis=0)
          
newdatabare=np.loadtxt('ModelOutput_p2s_frlnd_380.dat')
frlndbare=newdatabare.reshape((24,16))

Varbare=np.zeros((24,16))

for m in range(0,24):
    for n in range(0,16):
        if frlndbare[m,n]==0:
            Varbare[m,n]=1000
        else:
            Varbare[m,n]=(ts_bare[m,n]-(1-frlndbare[m,n])*sst_bare[m,n])/frlndbare[m,n]
                
Varbare=np.ma.masked_object(Varbare,1000)
                
Varbare_mean_zonal=np.sum(Varbare*frlndbare,axis=1)/np.sum(frlndbare,axis=1)#zonal mean
#print Var_mean_zonal
Landbare_mean_zonal=np.mean(frlndbare,axis=1)
Varbare_mean_zonal_weight=Varbare_mean_zonal[:]*Landbare_mean_zonal[:]*np.cos(pi_frac)[:]

weightsum1bare=np.sum(np.cos(pi_frac)*Landbare_mean_zonal)
Varbare_mean_0=np.sum(Varbare_mean_zonal_weight,axis=0)/weightsum1bare #mean
##############################################################################################
data_shrub=Dataset(nc_f_shrub, 'r')
ts_shrub =data_shrub.variables['ts'][0:1000,:,:]
ts_shrub=np.mean(ts_shrub,axis=0)

data_shrub=Dataset(nc_f_shrub, 'r')
sst_shrub =data_shrub.variables['sst'][0:1000,:,:]
sst_shrub=np.mean(sst_shrub,axis=0)
          
newdatashrub=np.loadtxt('ModelOutput_p2s_frlnd_380.dat')
frlndshrub=newdatashrub.reshape((24,16))
     

Varshrub=np.zeros((24,16))

for m in range(0,24):
    for n in range(0,16):
        if frlndshrub[m,n]==0:
            Varshrub[m,n]=1000
        else:
            Varshrub[m,n]=(ts_shrub[m,n]-(1-frlndshrub[m,n])*sst_shrub[m,n])/frlndshrub[m,n]
                
Varshrub=np.ma.masked_object(Varshrub,1000)
                
Varshrub_mean_zonal=np.sum(Varshrub*frlndshrub,axis=1)/np.sum(frlndshrub,axis=1)#zonal mean
#print Var_mean_zonal
Landshrub_mean_zonal=np.mean(frlndshrub,axis=1)
Varshrub_mean_zonal_weight=Varshrub_mean_zonal[:]*Landshrub_mean_zonal[:]*np.cos(pi_frac)[:]

weightsum1shrub=np.sum(np.cos(pi_frac)*Landshrub_mean_zonal)
Varshrub_mean_0=np.sum(Varshrub_mean_zonal_weight,axis=0)/weightsum1shrub #mean
##############################################################################################
data_tree=Dataset(nc_f_tree, 'r')
ts_tree =data_tree.variables['ts'][0:1000,:,:]
ts_tree=np.mean(ts_tree,axis=0)

data_tree=Dataset(nc_f_tree, 'r')
sst_tree =data_tree.variables['sst'][0:1000,:,:]
sst_tree=np.mean(sst_tree,axis=0)
          
newdatatree=np.loadtxt('ModelOutput_p2s_frlnd_380.dat')
frlndtree=newdatatree.reshape((24,16))
     

Vartree=np.zeros((24,16))

for m in range(0,24):
    for n in range(0,16):
        if frlndtree[m,n]==0:
            Vartree[m,n]=1000
        else:
            Vartree[m,n]=(ts_tree[m,n]-(1-frlndtree[m,n])*sst_tree[m,n])/frlndtree[m,n]
                
Vartree=np.ma.masked_object(Vartree,1000)
                
Vartree_mean_zonal=np.sum(Vartree*frlndtree,axis=1)/np.sum(frlndtree,axis=1)#zonal mean
#print Var_mean_zonal
Landtree_mean_zonal=np.mean(frlndtree,axis=1)
Vartree_mean_zonal_weight=Vartree_mean_zonal[:]*Landtree_mean_zonal[:]*np.cos(pi_frac)[:]

weightsum1tree=np.sum(np.cos(pi_frac)*Landtree_mean_zonal)
Vartree_mean_0=np.sum(Vartree_mean_zonal_weight,axis=0)/weightsum1tree #mean
##############################################################################################
data_early=Dataset(nc_f_early, 'r')
ts_early =data_early.variables['ts'][0:1000,:,:]
ts_early=np.mean(ts_early,axis=0)

data_early=Dataset(nc_f_early, 'r')
sst_early =data_early.variables['sst'][0:1000,:,:]
sst_early=np.mean(sst_early,axis=0)
          
newdataearly=np.loadtxt('ModelOutput_p2s_frlnd_380.dat')
frlndearly=newdataearly.reshape((24,16))
     

Varearly=np.zeros((24,16))

for m in range(0,24):
    for n in range(0,16):
        if frlndearly[m,n]==0:
            Varearly[m,n]=1000
        else:
            Varearly[m,n]=(ts_early[m,n]-(1-frlndearly[m,n])*sst_early[m,n])/frlndearly[m,n]
                
Varearly=np.ma.masked_object(Varearly,1000)
                
Varearly_mean_zonal=np.sum(Varearly*frlndearly,axis=1)/np.sum(frlndearly,axis=1)#zonal mean
#print Var_mean_zonal
Landearly_mean_zonal=np.mean(frlndearly,axis=1)
Varearly_mean_zonal_weight=Varearly_mean_zonal[:]*Landearly_mean_zonal[:]*np.cos(pi_frac)[:]

weightsum1early=np.sum(np.cos(pi_frac)*Landearly_mean_zonal)
Varearly_mean_0=np.sum(Varearly_mean_zonal_weight,axis=0)/weightsum1early #mean
##############################################################################################
data_middle=Dataset(nc_f_middle, 'r')
ts_middle =data_middle.variables['ts'][0:1000,:,:]
ts_middle=np.mean(ts_middle,axis=0)

data_middle=Dataset(nc_f_middle, 'r')
sst_middle =data_middle.variables['sst'][0:1000,:,:]
sst_middle=np.mean(sst_middle,axis=0)

newdatamiddle=np.loadtxt('ModelOutput_p2s_frlnd_380.dat')
frlndmiddle=newdatamiddle.reshape((24,16))
  
Varmiddle=np.zeros((24,16))

for m in range(0,24):
    for n in range(0,16):
        if frlndmiddle[m,n]==0:
            Varmiddle[m,n]=1000
        else:
            Varmiddle[m,n]=(ts_middle[m,n]-(1-frlndmiddle[m,n])*sst_middle[m,n])/frlndmiddle[m,n]
                
Varmiddle=np.ma.masked_object(Varmiddle,1000)
                
Varmiddle_mean_zonal=np.sum(Varmiddle*frlndmiddle,axis=1)/np.sum(frlndmiddle,axis=1)#zonal mean
#print Var_mean_zonal
Landmiddle_mean_zonal=np.mean(frlndmiddle,axis=1)
Varmiddle_mean_zonal_weight=Varmiddle_mean_zonal[:]*Landmiddle_mean_zonal[:]*np.cos(pi_frac)[:]

weightsum1middle=np.sum(np.cos(pi_frac)*Landmiddle_mean_zonal)
Varmiddle_mean_0=np.sum(Varmiddle_mean_zonal_weight,axis=0)/weightsum1middle #mean

##############################################################################################
data_late=Dataset(nc_f_late, 'r')
ts_late =data_late.variables['ts'][0:1000,:,:]
ts_late=np.mean(ts_late,axis=0)

data_late=Dataset(nc_f_late, 'r')
sst_late =data_late.variables['sst'][0:1000,:,:]
sst_late=np.mean(sst_late,axis=0)

newdatalate=np.loadtxt('ModelOutput_p2s_frlnd_380.dat')
frlndlate=newdatalate.reshape((24,16))

Varlate=np.zeros((24,16))

for m in range(0,24):
    for n in range(0,16):
        if frlndlate[m,n]==0:
            Varlate[m,n]=1000
        else:
            Varlate[m,n]=(ts_late[m,n]-(1-frlndlate[m,n])*sst_late[m,n])/frlndlate[m,n]
                
Varlate=np.ma.masked_object(Varlate,1000)
                
Varlate_mean_zonal=np.sum(Varlate*frlndlate,axis=1)/np.sum(frlndlate,axis=1)#zonal mean
#print Var_mean_zonal
Landlate_mean_zonal=np.mean(frlndlate,axis=1)
Varlate_mean_zonal_weight=Varlate_mean_zonal[:]*Landlate_mean_zonal[:]*np.cos(pi_frac)[:]

weightsum1late=np.sum(np.cos(pi_frac)*Landlate_mean_zonal)
Varlate_mean_0=np.sum(Varlate_mean_zonal_weight,axis=0)/weightsum1late #mean
               

print Varbare_mean_0
print Varshrub_mean_0
print Vartree_mean_0
print Varearly_mean_0
print Varmiddle_mean_0
print Varlate_mean_0