# This script creates Fig.1 of 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
import xlrd
import numpy as np
import matplotlib.pyplot as plt
import statsmodels.api as sm
import scipy.stats as st
import path
path.path = path.Path
import pyqt_fit.bootstrap as bs
import pyqt_fit.nonparam_regression as smooth
from pyqt_fit import npr_methods
from matplotlib import gridspec

#CO2 data from Foster et al. 2017, 419-359 Ma, with LOESS fit and 68% and 95% confidence interval given in the supplementary data 
#first column: age; 2: fit value; 3&5: lower and upper 95% value; 4&6: lower and upper 68% value
file_location = "co2fit.xlsx"
#data points from different proxies, given in supplementary material of Foster et al. 2018; 
# first column: age; 2: upper error bar age; 3: lower error bar age; 4: CO2; 5: lower error bar CO2; 6: upper error bar CO2
file_location_datapoints = "datapointsco2.xlsx"
workbook = xlrd.open_workbook(file_location)
first_sheet = workbook.sheet_by_index(0)

workbook_datapoints = xlrd.open_workbook(file_location_datapoints)
second_sheet = workbook_datapoints.sheet_by_index(0)

x = [first_sheet.cell_value(i, 0) for i in range(first_sheet.nrows)]
y = [first_sheet.cell_value(i, 1) for i in range(first_sheet.nrows)]
zeros=np.zeros(len(x))

x_datapoints = [second_sheet.cell_value(i, 0) for i in range(second_sheet.nrows)]
y_datapoints = [second_sheet.cell_value(i, 3) for i in range(second_sheet.nrows)]

yerr_pos95 = [first_sheet.cell_value(i, 5) for i in range(first_sheet.nrows)]
yerr_neg95 = [first_sheet.cell_value(i, 2) for i in range(first_sheet.nrows)]

yerr_pos68 = [first_sheet.cell_value(i, 4) for i in range(first_sheet.nrows)]
yerr_neg68 = [first_sheet.cell_value(i, 3) for i in range(first_sheet.nrows)]

yerr_pos_datapoints = [second_sheet.cell_value(i, 5)-y_datapoints[i] for i in range(second_sheet.nrows)]
yerr_neg_datapoints = [y_datapoints[i]-second_sheet.cell_value(i, 4) for i in range(second_sheet.nrows)]

xerr_pos_datapoints = [second_sheet.cell_value(i, 2)-x_datapoints[i] for i in range(second_sheet.nrows)]
xerr_neg_datapoints = [x_datapoints[i]-second_sheet.cell_value(i, 1) for i in range(second_sheet.nrows)]

xerr_datapoints = [xerr_neg_datapoints, xerr_pos_datapoints]
yerr_datapoints = [yerr_neg_datapoints, yerr_pos_datapoints]

#delta18O data from Joachimski, personal oommunication. delta 18O values from Joachimski et al. 2009, but different NBS120c standard for calibration (Lecuyer et al. 2003)
#first column: age; 2: old data (Joachimski2009); 3: data used in this figure, based on new standard
file_location_18o = "Joachimski18oDevonian.xlsx"
workbook = xlrd.open_workbook(file_location_18o)
first_sheet_18o = workbook.sheet_by_index(0)


x_18o = [first_sheet_18o.cell_value(i, 0) for i in range(first_sheet_18o.nrows)]
y_18o = [first_sheet_18o.cell_value(i, 2) for i in range(first_sheet_18o.nrows)]#this is the column for the updated data! old data in column 2

y_18o_fit_self = sm.nonparametric.lowess(y_18o,x_18o,frac=0.1, it=3, delta=0,is_sorted=False, missing='drop', return_sorted=True)

fg = plt.figure(figsize=(9,10))
gs = gridspec.GridSpec(3, 1, height_ratios=[0.5,6,6]) 
sp0=plt.subplot(gs[0])
ax = plt.gca()
#Stage names
ax.text(0.15,2.6,'Lochkovian',rotation=45,transform=ax.transAxes)
ax.text(0.23,2.6,'Pragian',rotation=45,transform=ax.transAxes)
ax.text(0.32,2.6,'Emsian',rotation=45,transform=ax.transAxes)
ax.text(0.45,2.6,'Eifelian',rotation=45,transform=ax.transAxes)
ax.text(0.52,2.6,'Givetian',rotation=45,transform=ax.transAxes)
ax.text(0.68,2.6,'Frasnian',rotation=45,transform=ax.transAxes)
ax.text(0.87,2.6,'Famennian',rotation=45,transform=ax.transAxes)

ax.invert_xaxis()
ax.tick_params(axis='x', top='on', labelbottom='on', labeltop='off')
plt.yticks([])
#time intervals
sp0.axvspan(416.0,411.2, color = 'mistyrose', alpha=0.7,zorder=1,lw=0)
sp0.axvspan(411.2,407.0, color = 'seashell', alpha=0.7,zorder=1,lw=0)
sp0.axvspan(407.0,397.5, color = 'navajowhite', alpha=0.7,zorder=1,lw=0)
sp0.axvspan(397.5,391.8, color = 'honeydew', alpha=0.7,zorder=1,lw=0)
sp0.axvspan(391.8,385.3, color = 'palegreen', alpha=0.7,zorder=1,lw=0)
sp0.axvspan(385.3,374.5, color = 'aliceblue', alpha=0.7,zorder=1,lw=0)
sp0.axvspan(374.5,359.2, color = 'paleturquoise', alpha=0.7,zorder=1,lw=0)


#PLOT A: CO2 concentration

sp1=plt.subplot(gs[1],sharex = sp0)
ax = plt.gca()
ax.invert_xaxis()
ax.tick_params(axis='both', top='on', labelbottom='off', labeltop='on')
#bands for three mass extinction pulses
sp1.axvspan(359.2,364, color = 'lightcoral', alpha=0.7,zorder=1,lw=0)
sp1.axvspan(378.1,374.5, color = 'lightcoral', alpha=0.7,zorder=1,lw=0)
sp1.axvspan(388.6,385.3, color = 'lightcoral', alpha=0.7,zorder=1,lw=0)
plt.fill_between(x,yerr_pos68,yerr_pos95,facecolor='lightgrey',linewidth=0,zorder=2)
plt.fill_between(x,y,yerr_pos68,facecolor='darkgrey',linewidth=0,zorder=2)
plt.fill_between(x,yerr_neg95,yerr_neg68,facecolor='lightgrey',linewidth=0,zorder=2)
plt.fill_between(x,yerr_neg68,y,facecolor='darkgrey',linewidth=0,zorder=2)
plt.plot(x,y,'k',linewidth=3,zorder=2)
plt.errorbar(x_datapoints, y_datapoints,xerr=xerr_datapoints,yerr=yerr_datapoints,color = 'k', fmt='o',zorder=3)
plt.ylim(-800,4000)

plt.ylabel('CO$\mathregular{_2}$ concentration [ppm]',fontsize=12)
sp1.set_title('(a)',x=-0.12,y=0.95,fontsize=12)


#PLOT B: delta_^18O

sp2=plt.subplot(gs[2], sharex = sp1)  
plt.subplots_adjust(wspace=0, hspace=0)
ax = plt.gca()
ax.invert_xaxis()
ax.invert_yaxis()
sp2.axvspan(359.2,364, color = 'lightcoral', alpha=0.7,zorder=1)
sp2.axvspan(378.1,374.5, color = 'lightcoral', alpha=0.7,zorder=1)
sp2.axvspan(388.6,385.3, color = 'lightcoral', alpha=0.7,zorder=1)
plt.plot(x_18o,y_18o,'k+',zorder=2) 
plt.plot(x_18o,y_18o_fit_self[:,1],'k-',zorder=2) 

ax.arrow(421.5, 17.8, 0,-2.0,width=0.2,head_width=0.7, head_length=0.3, fc='k', ec='k')
ax.annotate('warm', xy=(423.7,15.0),fontsize=12)
ax.arrow(421.5, 18.2, 0,2.0,width=0.2,head_width=0.7, head_length=0.3, fc='k', ec='k')
ax.annotate('cold', xy=(423,21.3),fontsize=12)

plt.xlim(425,358)  
plt.ylim(22,14.3)

plt.xlabel('Age [Ma]',fontsize=12)
plt.ylabel(u'$\mathregular{\delta^{18}}$O [\u2030 V-SMOW]',fontsize=12)
sp2.set_title('(b)',x=-0.12,y=0.95,fontsize=12)
fg.savefig('CO2_delta18O_Devonian_corrected.pdf', format='pdf',bbox_inches='tight')
