#This script creates Fig. 10 of 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
import numpy.ma as ma
from matplotlib.patches import Polygon
#create other color map
import matplotlib.colors as colors
from matplotlib.mlab import bivariate_normal
import matplotlib.colors as cl

from gradient import createGradient

cmap_ferretrainbow = createGradient(cmap=plt.cm.hsv_r,   unit='rgba', start=0.2,  end=1,   limit=16, output=False)

colormap_ferretrainbow = cl.LinearSegmentedColormap.from_list("printMap", cmap_ferretrainbow)

cmaplist_rainbow = [colormap_ferretrainbow(i) for i in range(colormap_ferretrainbow.N)]

cmap = colormap_ferretrainbow.from_list('Custom cmap', cmaplist_rainbow, colormap_ferretrainbow.N)


degree_sign= u'\N{DEGREE SIGN}'

lonlatpsdata=np.loadtxt('ModelOutput_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]
lonmid=lonlatpsdata[66:82]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))

#MOM grid for ice and continental contours
lonlatmomdata=np.loadtxt('ModelOutput_smom_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[97:193]
lat0mom=lonlatmomdata[193:242]
latmidmom=lonlatmomdata[242:290]

pi_frac_mom=(np.pi/180)*latmidmom[:]

cont=[415,380,360]
contname=['415','380','360']

#cont=[360,380]
#contname=['360','380']

#number=['0202','0402','0602','0802','1002','1202','1402','1602','1802','2002','2202','2402','2602','2802','3002','3202','3402','3602','3802','4002']
   
namesp2h=np.array(['tsann'])       

Namevarlong=np.array(['surface air temperature, annual mean [°C]' ])

Var_mean=np.zeros((len(contname),len(namesp2h)))

#create grid for maps
#atmosphere borders
lon2d, lat2d = np.meshgrid(lon,lat)
x=lon2d
y=lat2d

#ocean centers
lon2dmom, lat2dmom = np.meshgrid(lonmidmom,latmidmom)
xmom=lon2dmom
ymom=lat2dmom

#ocean border
lon2dmom0, lat2dmom0 = np.meshgrid(lon0mom,lat0mom)
xmom0=lon2dmom0
ymom0=lat2dmom0

minvar=-17
maxvar=36

Varcont=np.zeros((3,24,16))
Var_fs=np.zeros((3,24,16))
Varcont_ice=np.zeros((3,48,96))
temp=np.zeros((3,48,96))
u=np.zeros((3,48,96))
v=np.zeros((3,48,96))

count=0

Cont=np.zeros((3,48,96))

for j in range(len(contname)):

    #continent contours

    cont=np.loadtxt('ModelOutput_continents'+contname[j]+'.dat')
    cont=cont.reshape((2,48,96))
    cont=cont[0,:,:]#land ocean mask grid center
    Cont[j,:,:]=cont

    newdata=np.loadtxt('ModelOutput_p2h_'+contname[j]+'_bestguess.dat')
    newdata=newdata.reshape((4002,24,16))
    newdata=np.ma.masked_equal(newdata,-1)
    Varall=newdata[3002:4002,:,:] 
    Var=np.mean(Varall,axis=0)
    Varcont[j,:,:]=Var
    
    momdata=np.loadtxt('ModelOutput_momh_'+contname[j]+'_bestguess.dat')
    momdata=momdata.reshape((3,48,96))
    momdata=np.ma.masked_equal(momdata,-100)
    temp[j,:,:]=momdata[0,:,:] 
    temp=np.ma.masked_equal(temp,-100)
    u[j,:,:]=momdata[1,:,:] 
    u=np.ma.masked_equal(u,-100)
    v[j,:,:]=momdata[2,:,:] 
    v=np.ma.masked_equal(v,-100)
 
    newdata_ice=np.loadtxt('ModelOutput_isish_'+contname[j]+'_bestguess.dat')
    newdata_ice=newdata_ice.reshape((48,96))
    newdata_ice=np.ma.masked_equal(newdata_ice,-1)
    Varcont_ice[j,:,:]=newdata_ice
    for i in range(0,48):
        for k in range(0,96):
            if Varcont_ice[j,i,k]!=0: #if annual mean sea ice fraction is not zero, set it to 1, i.e., mark it as a cell with ice
                Varcont_ice[j,i,k]=1
                count=count+1
        
    xscatter=np.zeros(count)
    yscatter=np.zeros(count)
        
    count1=0
    
    #find grid cells in which annual mean sea ice fraction is not zero
    for i in range(0,48):
        for k in range(0,96):
            if Varcont_ice[j,i,k]!=0:
                    xscatter[count1]=lonmidmom[k]
                    yscatter[count1]=latmidmom[i]
                    count1=count1+1
                                        
    if j==0:
        xscatter415=xscatter
        yscatter415=yscatter
        
    elif j==1:
        xscatter380=xscatter
        yscatter380=yscatter
    elif j==2:
        xscatter360=xscatter  
        yscatter360=yscatter
        
fig,axes = plt.subplots(nrows=3, ncols=2,figsize=(10,10))
ax1=axes[0,0]
ax2=axes[1,0]
ax3=axes[2,0]
ax4=axes[0,1]
ax5=axes[1,1]
ax6=axes[2,1]

ax=[ax1,ax2,ax3,ax4,ax5,ax6]    

fig.subplots_adjust(left=0., right=1., bottom=0.1, top=0.9,wspace=0.01,hspace=0.4)    
  
#########################################################################################################################
#415 Ma ts
m = Basemap(ax=ax1,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
            llcrnrlon=0, urcrnrlon=360, resolution='c')

xscatter_415,yscatter_415=m(xscatter415,yscatter415)

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    
ax1.set_ylabel('415 Ma',rotation=0, size='large',x=0,y=0.5, labelpad=60)
ax1.set_title('(a)',x=-0.2,y=1.0,fontsize=10)    

levels=[0,1]
#surface air temperature
cs = m.pcolor(x,y,Varcont[0,:,:],latlon=True,cmap=colormap_ferretrainbow,vmin=minvar,vmax=maxvar)
#sea-ice contour
m.contour(xmom,ymom,Varcont_ice[0,:,:],1,colors='w')
#continent contour
m.contour(xmom,ymom,Cont[0,:,:],1,colors='k')
#scatter plot ice
m.scatter(xscatter_415[::2],yscatter_415[::2],facecolor='w',edgecolors='face',s=1)

#########################################################################################################################
#380 Ma ts
m = Basemap(ax=ax2,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')

xscatter_380,yscatter_380=m(xscatter380,yscatter380)

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    
ax2.set_ylabel('380 Ma',rotation=0, size='large',x=0,y=0.5, labelpad=60)
ax2.set_title('(b)',x=-0.2,y=1.0,fontsize=10)    

#surface air temperature
cs = m.pcolor(x,y,Varcont[1,:,:],latlon=True,cmap=colormap_ferretrainbow,vmin=minvar,vmax=maxvar)
#sea-ice contour
m.contour(xmom,ymom,Varcont_ice[1,:,:],1,colors='w')
#continent contour
m.contour(xmom,ymom,Cont[1,:,:],1,colors='k')
#scatter plot ice
m.scatter(xscatter_380[::2],yscatter_380[::2],facecolor='w',edgecolors='face',s=1)

###########################################################################################################################
#360 Ma ts
m = Basemap(ax=ax3,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')

xscatter_360,yscatter_360=m(xscatter360,yscatter360)

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    
ax3.set_ylabel('360 Ma',rotation=0, size='large',x=0,y=0.5, labelpad=60)
ax3.set_title('(c)',x=-0.2,y=1.0,fontsize=10)    
     
#surface air temperature
cs = m.pcolor(x,y,Varcont[2,:,:],latlon=True,cmap=colormap_ferretrainbow,vmin=minvar,vmax=maxvar)
#sea-ice contour
m.contour(xmom,ymom,Varcont_ice[2,:,:],1,colors='w')
#continent contour
m.contour(xmom,ymom,Cont[2,:,:],1,colors='k')
#scatter plot ice
m.scatter(xscatter_360[::2],yscatter_360[::2],facecolor='w',edgecolors='face',s=1)
###########################################################################################################################
#color bar
fig.subplots_adjust(bottom=0.15)
cbar_ax = fig.add_axes([0.1, 0.06, 0.3, 0.02])
cbar_ax.set_aspect('auto')

a=np.arange(minvar,maxvar,0.005)
t=(maxvar-minvar)/5
ticksbar=np.arange(minvar,maxvar,t)
#ticksbar=np.append(ticksbar,maxvar)

cbar=fig.colorbar(cs, cax=cbar_ax, orientation='horizontal',ticks=ticksbar,extend='both')            

cbar.set_label('Surface air temperature ['+degree_sign+'C]',fontsize=10)

#########################################################################################################################
#415 Ma temp
m = Basemap(ax=ax4,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
            llcrnrlon=0, urcrnrlon=360, resolution='c')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    
ax4.set_title('(d)',x=-0.2,y=1.0,fontsize=10)    

#temp
cs = m.pcolor(xmom0,ymom0,temp[0,:,:],latlon=True,cmap=colormap_ferretrainbow,vmin=-1,vmax=33)
m.quiver(xmom[::2,::3],ymom[::2,::3],u[0,::2,::3],v[0,::2,::3],latlon=True)#,scale=500,headlength=3,headaxislength=2)


#########################################################################################################################
#380 Ma temp
m = Basemap(ax=ax5,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
            llcrnrlon=0, urcrnrlon=360, resolution='c')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    
ax5.set_title('(e)',x=-0.2,y=1.0,fontsize=10)    

#temp
cs = m.pcolor(xmom0,ymom0,temp[1,:,:],latlon=True,cmap=colormap_ferretrainbow,vmin=-1,vmax=33)
m.quiver(xmom[::2,::3],ymom[::2,::3],u[1,::2,::3],v[1,::2,::3],latlon=True)#,scale=500,headlength=3,headaxislength=2)


###########################################################################################################################
#360 Ma temp
m = Basemap(ax=ax6,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
            llcrnrlon=0, urcrnrlon=360, resolution='c')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    
ax6.set_title('(f)',x=-0.2,y=1.0,fontsize=10)    

#temp
cs = m.pcolor(xmom0,ymom0,temp[2,:,:],latlon=True,cmap=colormap_ferretrainbow,vmin=-1,vmax=33)
Q=m.quiver(xmom[::2,::3],ymom[::2,::3],u[2,::2,::3],v[2,::2,::3],latlon=True)#,scale=500,headlength=3,headaxislength=2)
plt.quiverkey(Q,0.83,0.1,20,r'20 m/s', labelpos='E',
                   coordinates='figure')
###########################################################################################################################
#color bar
fig.subplots_adjust(bottom=0.15)
cbar_ax = fig.add_axes([0.6, 0.06, 0.3, 0.02])
cbar_ax.set_aspect('auto')

a=np.arange(minvar,maxvar,0.005)
t=(maxvar-minvar)/5
ticksbar=np.arange(-1,33,t)
ticksbar=np.append(ticksbar,33)

cbar=fig.colorbar(cs, cax=cbar_ax, orientation='horizontal',ticks=ticksbar,extend='both')            

cbar.set_label('Sea surface temperature ['+degree_sign+'C]',fontsize=10)
 
fig.savefig('Bestguess_maps_withsst.eps', format='eps',bbox_inches='tight') 
