#This script creates Fig. 12 in 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
# -*- coding: utf-8 -*-
"""
Spyder Editor

This is a temporary script file.
"""

import xlrd
import numpy as np
import matplotlib.pyplot as plt
import statsmodels.api as sm

#temperature data from Joachimski2009
#Column 1: age, 2: delta18O, 3: temperature; other columns are Loess fit with uncertainties which we do not use here
file_location_sst = "tempJoachimski2009withfit.xlsx"
workbook = xlrd.open_workbook(file_location_sst)
first_sheet_sst = workbook.sheet_by_index(0)

x_sst_datapoints_old = [first_sheet_sst.cell_value(i, 0) for i in range(first_sheet_sst.nrows)]
y_sst_datapoints_old = [first_sheet_sst.cell_value(i, 2) for i in range(first_sheet_sst.nrows)]

x_sst_old = [first_sheet_sst.cell_value(i, 3) for i in range(first_sheet_sst.nrows)]
y_sst_fit_self_old = sm.nonparametric.lowess(y_sst_datapoints_old,x_sst_datapoints_old,frac=0.1, it=3, delta=0,is_sorted=False, missing='drop', return_sorted=True)

#temperature data from Joachimski, personal communication, using a different calibration standard than in 2009 (Lecuyer et al. 2003) and a differnet temperature equation (Lecuyer et al. 2013 in column 3, different one (Pucéat et al. 2010) which is not shown in our plot in column 4). The LOESS fits shown in the plot are created with Python and therefore differ slightly from the one in Joachimski2009
file_location_sst = "tempJoachimskicorrected.xlsx"
workbook = xlrd.open_workbook(file_location_sst)
first_sheet_sst = workbook.sheet_by_index(0)

x_sst_datapoints = [first_sheet_sst.cell_value(i, 0) for i in range(first_sheet_sst.nrows)]
y_sst_datapoints1 = [first_sheet_sst.cell_value(i, 2) for i in range(first_sheet_sst.nrows)]
y_sst_datapoints2 = [first_sheet_sst.cell_value(i, 3) for i in range(first_sheet_sst.nrows)]

y_sst_fit1 = sm.nonparametric.lowess(y_sst_datapoints1,x_sst_datapoints,frac=0.1, it=10, delta=0.0,is_sorted=False, missing='drop', return_sorted=True)
y_sst_fit2 = sm.nonparametric.lowess(y_sst_datapoints2,x_sst_datapoints,frac=0.1, it=10, delta=0.0,is_sorted=False, missing='drop', return_sorted=True)

fg = plt.figure(figsize=(8,5))
ax = plt.gca()
ax.invert_xaxis()
ax.invert_yaxis()
plt.plot(x_sst_datapoints_old,y_sst_datapoints_old,'b+',alpha=0.8,zorder=1)
#plt.plot(x_sst_datapoints,y_sst_datapoints1,'k+',zorder=2)  
plt.plot(x_sst_datapoints,y_sst_datapoints2,'r+',alpha=0.8,zorder=1)  
#plt.plot(x_sst_datapoints,y_sst_fit1[:,1],'k',linewidth=3,zorder=2) 
plt.plot(x_sst_datapoints,y_sst_fit2[:,1],'r-',alpha=0.8,linewidth=2,zorder=1) 
plt.plot(x_sst_datapoints_old,y_sst_fit_self_old[:,1],'b--',alpha=0.8,linewidth=2,zorder=1) 

#Adding our own data from the best guess simulations
#SSTs averaged from 4003 to 5002 yearly snapshots, mom, -30,-10, average(-10,-30)
#22.4,29.3,27.1
#longitudinal min/max: 23.7/28.3
plt.errorbar(360,27.1,yerr=[[4.7],[2.2]],fmt='o',color='k',linewidth=2,capthick=2,zorder=2)
#24.2,30.4,28.3
#longitudinal min/max: 24.4/29.9
plt.errorbar(380,28.3,yerr=[[4.1],[2.1]],fmt='o',color='k',linewidth=2,capthick=2,zorder=2)
#25.2,30.9,28.9
#longitudinal min/max: 24.3/30.6
plt.errorbar(415,28.9,yerr=[[4.6],[2.0]],fmt='o',color='k',linewidth=2,capthick=2,zorder=2)

plt.xlim(425,358)  
plt.ylim(15,49)


plt.xlabel('Age [Ma]',fontsize=12)
plt.ylabel('SST [$\degree$C]',fontsize=12)
fg.savefig('SST_Devonian_correcteddata_withfit.pdf', format='pdf',bbox_inches='tight')
