# This script creates Fig.2 of #On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
#As the module used to plot maps in polar coordinates does not know periodic boundary conditions, the edges are connected manually
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
import numpy.ma as ma
from matplotlib.patches import Polygon
import cmocean
import matplotlib.colors as colors
from matplotlib.mlab import bivariate_normal
import matplotlib.colors as cl

from gradient import createGradient

class MidpointNormalize(colors.Normalize):
    def __init__(self, vmin=None, vmax=None, midpoint=None, clip=False):
        self.midpoint = midpoint
        colors.Normalize.__init__(self, vmin, vmax, clip)

    def __call__(self, value, clip=None):
        x, y = [self.vmin, self.midpoint, self.vmax], [0, 0.5, 1]
        return np.ma.masked_array(np.interp(value, x, y))

# Example for ocean colors
oceancolors = createGradient(cmap=cmocean.cm.ice,   unit='rgba', start=0.2,  end=1,   limit=16, output=False)
# Example for terrain colors
earthcolors = createGradient(cmap=cmocean.cm.turbid, unit='rgba', start=0.0, end=0.8, limit=16, output=False)

cmap=oceancolors+earthcolors
#cmap=cmocean.cm.ice+cmocean.cm.turbid
colormap = cl.LinearSegmentedColormap.from_list("printMap", cmap)

lonlatmomdata=np.loadtxt('ModelOutput_smom_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[97:193]
lat0mom=lonlatmomdata[193:242]
latmidmom=lonlatmomdata[242:290]

pi_frac_mom=(np.pi/180)*latmidmom[:]

cont=[360,380,415]
contname=['360','380','415']

#continent contours
cont360=np.loadtxt('ModelOutput_continents360.dat')
cont360=cont360.reshape((2,48,96))
cont360=cont360[0,:,:]#land ocean mask grid center

cont380=np.loadtxt('ModelOutput_continents380.dat')
cont380=cont380.reshape((2,48,96))
cont380=cont380[0,:,:]#land ocean mask grid center

cont415=np.loadtxt('ModelOutput_continents415.dat')
cont415=cont415.reshape((2,48,96))
cont415=cont415[0,:,:]#land ocean mask grid center

#grid for continents
lon2dcont, lat2dcont = np.meshgrid(lonmidmom, latmidmom)
xcont=lon2dcont
ycont=lat2dcont

#create grid for maps
lon2d, lat2d = np.meshgrid(lon0mom,lat0mom)
x=lon2d
y=lat2d

oro360=np.loadtxt('360Ma_oro.dat')#orography
oro380=np.loadtxt('380Ma_oro.dat')
oro415=np.loadtxt('415Ma_oro.dat')
kmt360=np.loadtxt('ModelOutput_kmt360.dat')#ocean depths; needs to be multiplicated with -1 as it is positive
kmt380=np.loadtxt('ModelOutput_kmt380.dat')
kmt415=np.loadtxt('ModelOutput_kmt415.dat')
OceanMask360=np.loadtxt('ModelOutput_OceanMask360.dat')#ocean cells=1, land cells=0
OceanMask380=np.loadtxt('ModelOutput_OceanMask380.dat')
OceanMask415=np.loadtxt('ModelOutput_OceanMask415.dat')
LandMask360=np.loadtxt('ModelOutput_LandMask360.dat')#ocean cells=0, land cells=1
LandMask380=np.loadtxt('ModelOutput_LandMask380.dat')
LandMask415=np.loadtxt('ModelOutput_LandMask415.dat')

depth=[0,25,50,75,126.5,159,203.4,265.1,349.4,460.8,603.1,779.7,992.7,1243.5,1532.7,1859.7,2223.1,2620.8,3049.4,3505.1,3983.4,4479,4986.5,5500]  
number=[1.,2.,3.,4.,5.,6.,7.,8.,9.,10.,11.,12.,13.,14.,15.,16.,17.,18.,19.,20.,21.,22.,23.,24.,25.]
for i in range(0,25):
    for k in range(len(lonmidmom)):
        for l in range(len(latmidmom)):
            if kmt360[l,k]==i:
                kmt360[l,k]=depth[i]  
                
            if kmt380[l,k]==i:
                kmt380[l,k]=depth[i] 
                
            if kmt415[l,k]==i:
                kmt415[l,k]=depth[i] 

kmt360=kmt360*OceanMask360
kmt360=-1*kmt360
kmt380=kmt380*OceanMask380
kmt380=-1*kmt380
kmt415=kmt415*OceanMask415
kmt415=-1*kmt415
       
oro360=(oro360*LandMask360)/100
oro380=(oro360*LandMask380)/100
oro415=(oro415*LandMask415)/100

sum415=oro415+kmt415
sum380=oro380+kmt380
sum360=oro360+kmt360

fig, axes = plt.subplots(nrows=3, ncols=2,figsize=(6,10))
ax1=axes[0,0]
ax2=axes[0,1]

ax3=axes[1,0]
ax4=axes[1,1]

ax5=axes[2,0]
ax6=axes[2,1]


###############################################################################
fig.subplots_adjust(left=0., right=1., bottom=0.2, top=0.7,wspace=0.2,hspace=0.4)
# Setup the map. See http://matplotlib.org/basemap/users/mapsetup.html
 # for other projections.


m = Basemap(ax=ax1,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False, False],color='grey',linewidth=0.5, fontsize=6)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',linewidth=0.5, fontsize=6)
            
cs = m.pcolor(x,y,sum415,norm=MidpointNormalize(midpoint=0.),cmap=colormap)      
ax1.set_ylabel('415 Ma',rotation=0, size='large',x=0,y=0.5, labelpad=60)
ax1.set_title('(a)',x=-0.1,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont415,1,colors='k')
############################################################################### 
m = Basemap(ax=ax2,projection='spstere',boundinglat=-26,lon_0=90,round='True',resolution='l')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)#,labels=[True,False,False,False],color='grey',fontsize=6)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=6)
            
cs = m.pcolor(x,y,sum415,norm=MidpointNormalize(midpoint=0.),latlon=True,cmap=colormap)
m.contour(xcont,ycont,cont415,1,latlon=True,colors='k')
#boundaries need to be plooted extra
a00,b00=m(1.9,-37.5)
a0,b0=m(0,-37.5)
a1,b1=m(0,-33.75)
a2,b2=m(0,-30.)
a3,b3=m(0,-26.25)

a=[a00,a0,a1,a2,a3]
b=[b00,b0,b1,b2,b3]
m.plot(a,b,'k-')
ax2.set_title('(b)',x=-0.1,y=1.1,fontsize=10)            
###############################################################################
m = Basemap(ax=ax3,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False, False],color='grey',linewidth=0.5,fontsize=6)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',linewidth=0.5,fontsize=6)
            
cs = m.pcolor(x,y,sum380,norm=MidpointNormalize(midpoint=0.),latlon=True,cmap=colormap)      
ax3.set_ylabel('380 Ma',rotation=0, size='large',x=0,y=0.5, labelpad=60)
ax3.set_title('(c)',x=-0.1,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k')
############################################################################### 
m = Basemap(ax=ax4,projection='spstere',boundinglat=-26,lon_0=90,round='True',resolution='l')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=6)
            
cs = m.pcolor(x,y,sum380,norm=MidpointNormalize(midpoint=0.),latlon=True,cmap=colormap)
m.contour(xcont,ycont,cont380,1,latlon=True,colors='k')  

a00,b00=m(349,-88.2)
a0,b0=m(359,-90)
a1,b1=m(82.5,-88)

a=[a00,a0,a1]
b=[b00,b0,b1]

m.plot(a,b,'k-')

a00,b00=m(359,-67.5)
a0,b0=m(1,-67.5)
a1a,b1b=m(359,-63.75)
a1,b1=m(0,-63.75)
a2,b2=m(0,-60)
a3,b3=m(1,-60)

a=[a00,a0]
b=[b00,b0]
m.plot(a,b,'k-')

a=[a1a,a1,a2,a3]
b=[b1b,b1,b2,b3]
m.plot(a,b,'k-')

ax4.set_title('(d)',x=-0.1,y=1.1,fontsize=10)                  
###############################################################################
m = Basemap(ax=ax5,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False, False],color='grey',linewidth=0.5,fontsize=6)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',linewidth=0.5,fontsize=6)
            
cs = m.pcolor(x,y,sum360,norm=MidpointNormalize(midpoint=0.),latlon=True,cmap=colormap)      
ax5.set_title('(e)',x=-0.1,y=1.1,fontsize=10)
ax5.set_ylabel('360 Ma',rotation=0, size='large',x=0,y=0.5, labelpad=60)
m.contour(xcont,ycont,cont360,1,colors='k')
############################################################################### 
m = Basemap(ax=ax6,projection='spstere',boundinglat=-26,lon_0=90,round='True',resolution='l')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),color='grey',linewidth=0.5)
m.drawmeridians(np.arange(0,360,45),labels=[True,True,True,True],color='grey',linewidth=0.5,fontsize=6)
            
cs = m.pcolor(x,y,sum360,norm=MidpointNormalize(midpoint=0.),latlon=True,cmap=colormap)
m.contour(xcont,ycont,cont360,1,latlon=True,colors='k')  

a00,b00=m(155,-88)
a0,b0=m(0,-90)
a1,b1=m(270,-88)


a=[a00,a0,a1]
b=[b00,b0,b1]

m.plot(a,b,'k-')

a00,b00=m(358,-78.7)
a0,b0=m(1,-78.7)

a=[a00,a0]
b=[b00,b0]

m.plot(a,b,'k-')

a00,b00=m(358,-71.25)
a0,b0=m(1,-71.25)

a=[a00,a0]
b=[b00,b0]

m.plot(a,b,'k-')

ax6.set_title('(f)',x=-0.1,y=1.1,fontsize=10)                  

fig.subplots_adjust(bottom=0.1)
cbar_ax = fig.add_axes([0.1, 0.06, 0.6, 0.01])
cbar_ax.set_aspect('auto')
ticksbar=np.arange(-4000,3000,1000)
cbar=fig.colorbar(cs, cax=cbar_ax, orientation='horizontal',ticks=ticksbar,extend='both')            
cbar.set_label('elevation [m]',fontsize=10)
 
fig.savefig('AllMaps.pdf', format='pdf',bbox_inches='tight') 
