#This script creates Fig. 4, On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from matplotlib.gridspec import GridSpec
from netCDF4 import Dataset
import sys

np.set_printoptions(threshold=sys.maxint)


lonlatpsdata=np.loadtxt('ModelOutput_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))

lonlatmomdata=np.loadtxt('ModelOutput_smom_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[97:193]
lat0mom=lonlatmomdata[193:242]
latmidmom=lonlatmomdata[242:290]

pi_frac_mom=(np.pi/180)*latmidmom[:]

#create grid for maps
lon2d, lat2d = np.meshgrid(lon, lat)
x=lon2d
y=lat2d

#############################################################################################################################
#1000 years data from yearly snapshots
nc_f_bare = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_bare/cdo_1000years/snapshots_potsdam2-1000years-yearmean_as_e_qi.nc'
nc_f_shrub = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_shrubcover/cdo_1000years/snapshots_potsdam2-1000years-yearmean_as_e_qi.nc'
nc_f_tree = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_treecover/cdo_1000years/snapshots_potsdam2-1000years-yearmean_as_e_qi.nc'
nc_f_early = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_earlydevveg/cdo_1000years/snapshots_potsdam2-1000years-yearmean_as_e_qi.nc'
nc_f_middle = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_middledevveg/cdo_1000years/snapshots_potsdam2-1000years-yearmean_as_e_qi.nc'
nc_f_late = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_latedevveg/cdo_1000years/snapshots_potsdam2-1000years-yearmean_as_e_qi.nc'

nc_f_bare_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_bare/history_p2.nc'
nc_f_shrub_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_shrubcover/history_p2.nc'
nc_f_tree_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_treecover/history_p2.nc'
nc_f_early_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_earlydevveg/history_p2.nc'
nc_f_middle_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_middledevveg/history_p2.nc'
nc_f_late_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_latedevveg/history_p2.nc'

vegetation=[nc_f_bare,nc_f_shrub,nc_f_tree,nc_f_early,nc_f_middle,nc_f_late]


data_bare=Dataset(nc_f_bare, 'r')
sa_bare =data_bare.variables['as'][0:1000,:,:]
sa_bare=np.mean(sa_bare,axis=0)
e_bare =data_bare.variables['e'][0:1000,:,:]
e_bare=np.mean(e_bare,axis=0)
qi_bare =data_bare.variables['qi'][0:1000,:,:]
qi_bare=np.mean(qi_bare,axis=0)
historydata_bare = Dataset(nc_f_bare_history, 'r')
tsann_bare=historydata_bare.variables['ts_ann'][5302:6302,:,:]
tsann_bare=np.mean(tsann_bare,axis=0)

data_shrub=Dataset(nc_f_shrub, 'r')
sa_shrub =data_shrub.variables['as'][0:1000,:,:]
sa_shrub=np.mean(sa_shrub,axis=0)
e_shrub =data_shrub.variables['e'][0:1000,:,:]
e_shrub=np.mean(e_shrub,axis=0)
qi_shrub =data_shrub.variables['qi'][0:1000,:,:]
qi_shrub=np.mean(qi_shrub,axis=0)
historydata_shrub = Dataset(nc_f_shrub_history, 'r')
tsann_shrub=historydata_shrub.variables['ts_ann'][4003:5003,:,:]
tsann_shrub=np.mean(tsann_shrub,axis=0)

data_tree=Dataset(nc_f_tree, 'r')
sa_tree =data_tree.variables['as'][0:1000,:,:]
sa_tree=np.mean(sa_tree,axis=0)
e_tree =data_tree.variables['e'][0:1000,:,:]
e_tree=np.mean(e_tree,axis=0)
qi_tree =data_tree.variables['qi'][0:1000,:,:]
qi_tree=np.mean(qi_tree,axis=0)
historydata_tree = Dataset(nc_f_tree_history, 'r')
tsann_tree=historydata_tree.variables['ts_ann'][4003:5003,:,:]
tsann_tree=np.mean(tsann_tree,axis=0)

data_early=Dataset(nc_f_early, 'r')
sa_early =data_early.variables['as'][0:1000,:,:]
sa_early=np.mean(sa_early,axis=0)
e_early =data_early.variables['e'][0:1000,:,:]
e_early=np.mean(e_early,axis=0)
qi_early =data_early.variables['qi'][0:1000,:,:]
qi_early=np.mean(qi_early,axis=0)
historydata_early = Dataset(nc_f_early_history, 'r')
tsann_early=historydata_early.variables['ts_ann'][4003:5003,:,:]
tsann_early=np.mean(tsann_early,axis=0)

data_middle=Dataset(nc_f_middle, 'r')
sa_middle =data_middle.variables['as'][0:1000,:,:]
sa_middle=np.mean(sa_middle,axis=0)
e_middle =data_middle.variables['e'][0:1000,:,:]
e_middle=np.mean(e_middle,axis=0)
qi_middle =data_middle.variables['qi'][0:1000,:,:]
qi_middle=np.mean(qi_middle,axis=0)
historydata_middle = Dataset(nc_f_middle_history, 'r')
tsann_middle=historydata_middle.variables['ts_ann'][4003:5003,:,:]
tsann_middle=np.mean(tsann_middle,axis=0)

data_late=Dataset(nc_f_late, 'r')
sa_late =data_late.variables['as'][0:1000,:,:]
sa_late=np.mean(sa_late,axis=0)
e_late =data_late.variables['e'][0:1000,:,:]
e_late=np.mean(e_late,axis=0)
qi_late =data_late.variables['qi'][0:1000,:,:]
qi_late=np.mean(qi_late,axis=0)
historydata_late = Dataset(nc_f_late_history, 'r')
tsann_late=historydata_late.variables['ts_ann'][4003:5003,:,:]
tsann_late=np.mean(tsann_late,axis=0)
####################################################################################################
cont380=np.loadtxt('ModelOutput_continents380.dat')
cont380=cont380.reshape((2,48,96))
cont380=cont380[0,:,:]#land ocean mask grid center
    #grid for continents
lon2dcont380, lat2dcont380 = np.meshgrid(lonmidmom, latmidmom)
xcont=lon2dcont380
ycont=lat2dcont380            
####################################################################################################
Varall=[tsann_early-tsann_bare,tsann_middle-tsann_bare,tsann_late-tsann_bare, tsann_shrub-tsann_bare, tsann_tree-tsann_bare, e_early-e_bare,e_middle-e_bare,e_late-e_bare,e_shrub-e_bare,e_tree-e_bare,sa_early-sa_bare,sa_middle-sa_bare,sa_late-sa_bare,sa_shrub-sa_bare,sa_tree-sa_bare,qi_early-qi_bare,qi_middle-qi_bare,qi_late-qi_bare,qi_shrub-qi_bare,qi_tree-qi_bare]

fig = plt.figure(figsize=(12,12))

gs=GridSpec(8,4, width_ratios=[8,8,8,8],height_ratios=[1,1,0.1,0.1,1,1,1,0.1])

ax1=plt.subplot(gs[0,0])
ax2=plt.subplot(gs[0,1])
ax3=plt.subplot(gs[0,2])
ax4=plt.subplot(gs[0,3])

ax5=plt.subplot(gs[1,0])
ax6=plt.subplot(gs[1,1])
ax7=plt.subplot(gs[1,2])
ax8=plt.subplot(gs[1,3])

bar1=plt.subplot(gs[2,0])
bar2=plt.subplot(gs[2,1])
bar3=plt.subplot(gs[2,2])
bar4=plt.subplot(gs[2,3])

bar1extra=plt.subplot(gs[3,0])
bar2extra=plt.subplot(gs[3,1])
bar3extra=plt.subplot(gs[3,2])
bar4extra=plt.subplot(gs[3,3])

ax9=plt.subplot(gs[4,0])
ax10=plt.subplot(gs[4,1])
ax11=plt.subplot(gs[4,2])
ax12=plt.subplot(gs[4,3])

ax13=plt.subplot(gs[5,0])
ax14=plt.subplot(gs[5,1])
ax15=plt.subplot(gs[5,2])
ax16=plt.subplot(gs[5,3])

ax17=plt.subplot(gs[6,0])
ax18=plt.subplot(gs[6,1])
ax19=plt.subplot(gs[6,2])
ax20=plt.subplot(gs[6,3])

bar5=plt.subplot(gs[7,0])
bar6=plt.subplot(gs[7,1])
bar7=plt.subplot(gs[7,2])
bar8=plt.subplot(gs[7,3])
###############################################################################
plt.figtext(0.2,0.9,'Surface air'+'\n'+'temperature',fontsize=12, horizontalalignment='center')
plt.figtext(0.42,0.9,'Evaporation',fontsize=12,horizontalalignment='center')
plt.figtext(0.62,0.9,'Surface albedo',fontsize=12,horizontalalignment='center')
plt.figtext(0.82,0.9,'Atmospheric water'+'\n'+'vapor content',fontsize=12,horizontalalignment='center')

plt.subplots_adjust(wspace=0.2, hspace=0.2)

###############################################################################
m = Basemap(ax=ax1,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs1 = m.pcolor(x,y,Varall[3],latlon=True,cmap=plt.cm.bwr,vmin=-5.5,vmax=5.5) 
ax1.set_title('(a)',x=0.0,y=1.1,fontsize=10)   
#ax13.set_ylabel(u'Shrub \u2212 Bare',rotation=0, fontsize=12,fontweight='semibold',y=0.4, labelpad=70)
m.contour(xcont,ycont,cont380,1,colors='k')  
###############################################################################
m = Basemap(ax=ax2,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs2 = m.pcolor(x,y,Varall[8],latlon=True,cmap=plt.cm.bwr,vmin=-7,vmax=7)       
ax2.set_title('(b)',x=0.0,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k')  
############################################################################### 
m = Basemap(ax=ax3,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs3 = m.pcolor(x,y,Varall[13],latlon=True,cmap=plt.cm.bwr,vmin=-0.35,vmax=0.35) 
ax3.set_title('(c)',x=0.0,y=1.1,fontsize=10)   
m.contour(xcont,ycont,cont380,1,colors='k')           
###############################################################################
m = Basemap(ax=ax4,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)
            
cs4 = m.pcolor(x,y,Varall[18],latlon=True,cmap=plt.cm.bwr,vmin=-0.7,vmax=0.7)       
ax4.set_title('(d)',x=0.0,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k')  
###############################################################################
###############################################################################
###############################################################################
m = Basemap(ax=ax5,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs = m.pcolor(x,y,Varall[4],latlon=True,cmap=plt.cm.bwr,vmin=-5.5,vmax=5.5) 
ax5.set_title('(e)',x=0.0,y=1.1,fontsize=10)   
#ax17.set_ylabel(u'Tree \u2212 Bare',rotation=0, fontsize=12,fontweight='semibold',y=0.4, labelpad=70)
m.contour(xcont,ycont,cont380,1,colors='k')  
###############################################################################
m = Basemap(ax=ax6,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs = m.pcolor(x,y,Varall[9],latlon=True,cmap=plt.cm.bwr,vmin=-7,vmax=7)       
ax6.set_title('(f)',x=0.0,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k')  
############################################################################### 
m = Basemap(ax=ax7,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs = m.pcolor(x,y,Varall[14],latlon=True,cmap=plt.cm.bwr,vmin=-0.35,vmax=0.35) 
ax7.set_title('(g)',x=0.0,y=1.1,fontsize=10)   
m.contour(xcont,ycont,cont380,1,colors='k')           
###############################################################################
m = Basemap(ax=ax8,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)
            
cs = m.pcolor(x,y,Varall[19],latlon=True,cmap=plt.cm.bwr,vmin=-0.7,vmax=0.7)       
ax8.set_title('(h)',x=0.0,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k')  
###############################################################################
###############################################################################
###############################################################################
cbar=plt.colorbar(cs1, cax=bar1, ticks=[-5,-3,0,3,5],orientation='horizontal',extend='both')            
cbar.set_label('[$\degree$C]',fontsize=10)               
############################################################################### 
cbar=plt.colorbar(cs2, cax=bar2,ticks=[-7,-4,0,4,7],orientation='horizontal',extend='both')            
cbar.set_label('[mm/day]',fontsize=10)  
############################################################################### 
cbar=plt.colorbar(cs3, cax=bar3, ticks=[-0.3,-0.1,0.1,0.3],orientation='horizontal',extend='both')            
#cbar.set_label('surface albedo',fontsize=10)   
###############################################################################
cbar=plt.colorbar(cs4, cax=bar4,ticks=[-0.7,-0.4,0,0.4,0.7],orientation='horizontal',extend='both')            
cbar.set_label('[kg/m$^2$]',fontsize=10)
###############################################################################
###############################################################################
###############################################################################
bar1extra.axis('off')
bar2extra.axis('off')
bar3extra.axis('off')
bar4extra.axis('off')
###############################################################################
###############################################################################
###############################################################################
m = Basemap(ax=ax9,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)
            
cs5 = m.pcolor(x,y,Varall[0],latlon=True,cmap=plt.cm.bwr,vmin=-2.5,vmax=2.5)      
ax9.set_title('(i)',x=0.0,y=1.1,fontsize=10)
#ax1.set_ylabel(u'Early \u2212 Bare',rotation=0, fontsize=12,fontweight='semibold',y=0.4, labelpad=70)
#ax1.set_title('415 Ma',x=0.2,y=1.2,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k')  
#cbar=fig.colorbar(cs, orientation='horizontal',extend='both')            
#cbar.set_label('elevation [m]',fontsize=12)
############################################################################### 
m = Basemap(ax=ax10,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)
            
cs6 = m.pcolor(x,y,Varall[5],latlon=True,cmap=plt.cm.bwr,vmin=-2.5,vmax=2.5)
ax10.set_title('(j)',x=0.0,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k') 
############################################################################### 
m = Basemap(ax=ax11,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)
            
cs7 = m.pcolor(x,y,sa_early-sa_bare,latlon=True,cmap=plt.cm.bwr,vmin=-0.1,vmax=0.1)
ax11.set_title('(k)',x=0.0,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k') 
###############################################################################
m = Basemap(ax=ax12,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)
            
cs8 = m.pcolor(x,y,Varall[15],latlon=True,cmap=plt.cm.bwr,vmin=-0.3,vmax=0.3)
ax12.set_title('(l)',x=0.0,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k') 
###############################################################################
###############################################################################
############################################################################### 
m = Basemap(ax=ax13,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)
            
cs = m.pcolor(x,y,Varall[1],latlon=True,cmap=plt.cm.bwr,vmin=-2.5,vmax=2.5)      
ax13.set_title('(m)',x=0.0,y=1.1,fontsize=10)
#ax5.set_ylabel(u'Middle \u2212 Bare',rotation=0, fontsize=12,fontweight='semibold',y=0.4, labelpad=70)
m.contour(xcont,ycont,cont380,1,colors='k')
############################################################################### 
m = Basemap(ax=ax14,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)
            
cs = m.pcolor(x,y,Varall[6],latlon=True,cmap=plt.cm.bwr,vmin=-2.5,vmax=2.5)      
ax14.set_title('(n)',x=0.0,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k')                 
############################################################################### 
m = Basemap(ax=ax15,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs = m.pcolor(x,y,sa_middle-sa_bare,latlon=True,cmap=plt.cm.bwr,vmin=-0.1,vmax=0.1)       
ax15.set_title('(o)',x=0.0,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k')  
############################################################################### 
m = Basemap(ax=ax16,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs = m.pcolor(x,y,Varall[16],latlon=True,cmap=plt.cm.bwr,vmin=-0.3,vmax=0.3) 
ax16.set_title('(p)',x=0.0,y=1.1,fontsize=10)   
m.contour(xcont,ycont,cont380,1,colors='k')  
###############################################################################
############################################################################### 
############################################################################### 
m = Basemap(ax=ax17,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs = m.pcolor(x,y,Varall[2],latlon=True,cmap=plt.cm.bwr,vmin=-2.5,vmax=2.5) 
ax17.set_title('(q)',x=0.0,y=1.1,fontsize=10)   
#ax9.set_ylabel(u'Late \u2212 Bare',rotation=0, fontsize=12,fontweight='semibold',y=0.4, labelpad=70)
m.contour(xcont,ycont,cont380,1,colors='k')  
###############################################################################
m = Basemap(ax=ax18,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs = m.pcolor(x,y,Varall[7],latlon=True,cmap=plt.cm.bwr,vmin=-2.5,vmax=2.5)       
ax18.set_title('(r)',x=0.0,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k')  
############################################################################### 
m = Basemap(ax=ax19,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs = m.pcolor(x,y,sa_late-sa_bare,latlon=True,cmap=plt.cm.bwr,vmin=-0.1,vmax=0.1) 
ax19.set_title('(s)',x=0.0,y=1.1,fontsize=10)   
m.contour(xcont,ycont,cont380,1,colors='k')           
###############################################################################
m = Basemap(ax=ax20,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)
            
cs = m.pcolor(x,y,Varall[17],latlon=True,cmap=plt.cm.bwr,vmin=-0.3,vmax=0.3)       
ax20.set_title('(t)',x=0.0,y=1.1,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k')  
###############################################################################
###############################################################################
###############################################################################
cbar=plt.colorbar(cs5, cax=bar5, ticks=[-2,-1,0,1,2],orientation='horizontal',extend='both')            
cbar.set_label('[$\degree$C]',fontsize=10)               
############################################################################### 
cbar=plt.colorbar(cs6, cax=bar6,ticks=[-2,-1,0,1,2],orientation='horizontal', extend='both')            
cbar.set_label('[mm/day]',fontsize=10)  
############################################################################### 
cbar=plt.colorbar(cs7, cax=bar7, ticks=[-0.1,0,0.1],orientation='horizontal',extend='both')            
#cbar.set_label('surface albedo',fontsize=10)   
###############################################################################
cbar=plt.colorbar(cs8, cax=bar8,ticks=[-0.3,-0.1,0.1,0.3],orientation='horizontal',extend='both')            
cbar.set_label('[kg/m$^2$]',fontsize=10)


fig.savefig('Vegetation_Devoniantimes_plus_extremescenarios_1000years.pdf', format='pdf',bbox_inches='tight')    
