require, "asciilib.i";
require, "graphlib.i";
require, "geolib.i";
require, "climber3a.i";
include, "ncops.i";


// Figure 5, „On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation“
func devn_plot_orbital( season= )
{

  // read model temperature data file:
  local o, e, p, t;
  if( is_void(season) )
    read_columns, "ModelOutput/devn_380Ma_temp.dat",
      1,o, 2,e, 3,p, 4,t;
  else{
    if( season=="djf" )
      read_columns, "ModelOutput/devn_380Ma_temp_djf.dat",
        1,o, 2,e, 3,p, 4,t;
    if( season=="jja" )
      read_columns, "ModelOutput/devn_380Ma_temp_jja.dat",
        1,o, 2,e, 3,p, 4,t;
  }
      

  // convert p to radians:
  p *= pi/180.;

  // get min and max temperature for color scaling:
  tmin = min( t );
  tmax = max( t );
  tmin; tmax;
  //  tmin = 21.0; tmax = 21.6;
  //  tmin; tmax;

  // create coordinate arrays in low resolution (with p array expanded
  // to ensure cyclic boundary condition):
  e_l = [0.,0.030,0.069];
  p_l = span( 0., 315., 8 )/180.*pi;
  d_p_l = p_l(2)-p_l(1);
  p_l_c = [-d_p_l];
  grow, p_l_c, p_l;
  grow, p_l_c, [2.*pi,2.*pi+d_p_l];
  p_l = p_l_c;
  // 2d arrays:
  e_l2 = e_l(-:1:numberof(p_l),);
  p_l2 = p_l(,-:1:numberof(e_l));

  // create high-resolution coordinate arrays for interpolation:
  nn = 400;
  e_h = span( 0., 0.069, nn );
  p_h = span( 0., 2.*pi, nn );
  // 2d arrays:
  e_h2 = e_h(-:1:nn,);
  p_h2 = p_h(,-:1:nn);


  // initialise display:
  fma;
  // print white text to adjust bounding box:
  plt, "E", 0.016, 0.621, color="white"; // upper left corner
  plt, "E", 0.915, 0.22, color="white"; // lower right corner


  oo = [22.0,23.5,24.5];

  for( no=1; no<=3; no++ ){
  
    // select values:
    w = where( o==oo(no) & t>-9. );
    ee = e(w); pp = p(w); tt = t(w);

    // map temperature to 2d array:
    t_l2 = e_l2*0.;
    for( ne=1; ne<=numberof(e_l); ne++ ){
      for( np=2; np<numberof(p_l)-1; np++ ){
        if( e_l(ne)==0. )
          t_l2(np,ne) = tt(where( ee==e_l(ne) )(1) );
        else
          t_l2(np,ne) = tt( where( pp==p_l(np) & ee==e_l(ne) ) );
      }
    }
    // expanded array to ensure cyclic boundary conditions:
    t_l2(1,)  = t_l2(9,);
    t_l2(10,) = t_l2(2,);
    t_l2(11,) = t_l2(3,);


    // interpolate to high-resolution grid:
    t_h2 = interp2( e_h2, p_h2, t_l2, e_l2, p_l2 );

    // remap to Cartesian coordinates:
    x_h2 = e_h2*sin(p_h2);
    y_h2 = e_h2*cos(p_h2);
    x_p = y_p = span( -0.069, +0.069, nn );
    x_p2 = x_p(-:1:numberof(y_p),);
    y_p2 = y_p(,-:1:numberof(x_p));
    t_p2 = interp2( x_p2, y_p2, t_h2, x_h2, y_h2, outside=(tmin+tmax)/2. );
    //    t_p2 = interp2( x_p2, y_p2, t_h2, x_h2, y_h2, outside=tmax+0.1 );

    //    place_plsys, no, 0.09+(no-1)*0.32, 0.34+(no-1)*0.32, 0.35, 0.6,
    //      landscape=1, tlabel_height=14, fwidth=3, nmajor=4, nminor=1;
    if( no==1 )
      place_plsys, 1, 0.09, 0.34, 0.35, 0.60, tmark_r=0,
        landscape=1, tlabel_height=14, fwidth=3, nmajor=4, nminor=1;
    if( no==2 )
      place_plsys, 2, 0.3413, 0.5926, 0.35, 0.60, tmark_l=0, tmark_r=0,
        landscape=1, tlabel_height=14, fwidth=3, nmajor=4, nminor=1;
    if( no==3 )
      place_plsys, 3, 0.5939, 0.8452, 0.35, 0.60, tlabel_r=1, tmark_r=1,
        tmark_l=0, tlabel_l=0,
        landscape=1, tlabel_height=14, fwidth=3, nmajor=4, nminor=1;
    plsys, no;
    // plot interpolated temperature values:
    pli, t_p2, -0.069, -0.069, 0.069, 0.069, cmin=tmin, cmax=tmax;
    // plot black circle at maximum excentricity:
    plg, 0.0689*cos(p_h), 0.0689*sin(p_h), width=2, color="black";
    // define color palette:
    //    r = indgen(5:205:2);   grow, r, [255,255], indgen(254:154:-1);
    //    g = indgen(0:200:2);   grow, g, [255,255], indgen(200:0:-2);
    //    b = indgen(154:254:1); grow, b, [255,255], indgen(205:5:-2);
    //    r = indgen(5:205:2);   grow, r, indgen(254:154:-1), [255,255];
    //    g = indgen(0:200:2);   grow, g, indgen(200:0:-2), [255,255];
    //    b = indgen(154:254:1); grow, b, indgen(205:5:-2), [255,255];
    r = indgen(0:250:2);   grow, r, indgen(254:129:-1);
    g = indgen(0:250:2);   grow, g, indgen(250:0:-2);
    b = indgen(129:254:1); grow, b, indgen(250:0:-2);
    palette, r, g, b;
    // plot individual simulation points:
    plmk, ee*cos(pp), ee*sin(pp), marker=4,msize=.3, color="white";
    plmk, ee*cos(pp), ee*sin(pp), marker=4,msize=.2;
    limits, -0.095, 0.095, -0.095, 0.095;
    // month of perihelion passage: I have double checked this with
    // simulation output; however, the precession angle definition is
    // different from De Vleeschouwer et al. (2014)! we might wish to
    // change this at some point...
    months=["Sep","Oct","Nov","Dec","Jan","Feb",
            "Mar","Apr","May","Jun","Jul","Aug"];
    angle=span( 0., 330., 12 )/180.*pi;
    for( nm=1; nm<=12; nm++ )
      plt, months(nm), 0.079*sin(angle(nm)), 0.079*cos(angle(nm)), 
        height=8, justify="CH", tosys=1, color=[65,65,65],
        font="helveticaI";
    // title and legends:
    pltitle_height=24;
    pltitle_height=16;
    //    pltitle, swrite( format="!e = %4.1f%c", oo(no), 176 );
    pltitle_height=14;
    if( no==1 ){
      plt, "(a)", -0.085, 0.075, tosys=1;
      plt, swrite( format="!e = %4.1f%c", oo(no), 176 ), 0.21565, 0.62,
        justify="CH";
      xytitles, "e sin (!w)", "e cos (!w)", [0.,0.014];
    }
    if( no==2 ){
      plt, "(b)", -0.085, 0.075, tosys=1;
      plt, swrite( format="!e = %4.1f%c", oo(no), 176 ), 0.46695, 0.62,
        justify="CH";
      xytitles, "e sin (!w)", "", [0.,0.014];
    }
    if( no==3 ){
      plt, "(c)", -0.085, 0.075, tosys=1;
      plt, swrite( format="!e = %4.1f%c", oo(no), 176 ),0.71955, 0.62,
        justify="CH";
      xytitles, "e sin (!w)", "", [0.,0.014];
      rightytitle, "e cos (!w)", offset=0.055;
    }

  }

  // color bar:
  place_plsys, 4, 0.31, 0.76, 0.25, 0.26;
  colorbar_, tmin, tmax, sys=4, viewport=[0.2813,0.6526,0.25,0.265], 
    nmajor=10, nminor=0, tlabel_b=1, horizontal=1,
    tlabel_height=12;
  plsys, 4;
  //  plt, swrite( format="%cC", 176 ), 0.77, 0.228, height=12;
  plt, swrite( format="Annual Global Mean Temperature (%cC)", 176 ), 
    0.46695, 0.212, justify="CH", height=12;



  // hard copy:
  if( is_void(season) )
    out = "Plots/devn_temp_orbital";
  else{
    if( season=="djf" )
      out = "Plots/devn_temp_orbital_djf";
    if( season=="jja" )
      out = "Plots/devn_temp_orbital_jja";
  }
  pdf, out;
  png, out, dpi=600;

}
