# This script creates the inner plot of Fig.7 of 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
import numpy.ma as ma
from matplotlib.patches import Polygon
from matplotlib.pyplot import text
import matplotlib.patches as mpatch

degree_sign= u'\N{DEGREE SIGN}'

lonlatpsdata=np.loadtxt('ModelOutput_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))
weightsum_north_p2=np.sum(np.cos(pi_frac)[20:24])

lonlatmomdata=np.loadtxt('ModelOutput_isis_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[194:29]
lat0mom=lonlatmomdata[98:145]
latmidmom=lonlatmomdata[146:194]

pi_frac_mom=(np.pi/180)*latmidmom[:]

weightsum_mom=np.sum(np.cos(pi_frac_mom))

weightsum_north_mom=np.sum(np.cos(pi_frac_mom)[40:48])

oblname=['24p5']


#namesp2h=np.array(['tsann','tsdjf','tsjja'])      
nameisish=np.array(['con_g'])       

Namevarlong=np.array(['ice fraction'])

count=np.zeros(8)
#create grid for maps
lon2d, lat2d = np.meshgrid(lon,lat)
x=lon2d
y=lat2d
        
#Arctic ice fraction
newdata=np.loadtxt('ModelOutput_isish_24p5_3600s.dat')
newdata=newdata.reshape((3802,48,96))
newdata=np.ma.masked_equal(newdata,-1)
Varnorth=newdata[2950:3250,40:48,:] 
Varnorth_zonal_mean=np.mean(Varnorth,axis=2)
Var_mean_zonal_weight=Varnorth_zonal_mean[:]*np.cos(pi_frac_mom)[40:48]#weighted zonal mean 
Var_mean_north_ice=np.sum(Var_mean_zonal_weight,axis=1)/weightsum_north_mom #mean             
###############################################################################
#Arctic temperatrue
newdata=np.loadtxt('ModelOutput_p2h_24p5_3600s.dat')
newdata=newdata.reshape((3802,24,16))
Var=newdata[2950:3250,20:24,:] 
Var_zonal_mean_north=np.mean(Var,axis=2)
Var_mean_zonal_weight_north=Var_zonal_mean_north[:]*np.cos(pi_frac[20:24])#weighted zonal mean 
Var_mean_north=np.sum(Var_mean_zonal_weight_north,axis=1)/weightsum_north_p2#mean 
       
fig, ax1 = plt.subplots()

       

time=np.arange(150,450)

major_xticks=np.arange(150,450,100)
minor_xticks=np.arange(150,400,10)

line1=ax1.plot(time,Var_mean_north,'k-',linewidth=3.0,label='temperature')
ax1.set_xlabel('time [yrs]',color='k',fontsize='12')
ax1.set_ylabel('Arctic temperature ['+degree_sign+'C]',color='k',fontsize='12')
ax1.set_ylim(3.3,5.3)


ax1.vlines(x=190, ymin=3.3, ymax=5.3, color = 'r')
ax1.text(195,5.2, "1" ,verticalalignment='center',color='k',weight='bold')
ax1.vlines(x=240, ymin=3.3, ymax=5.3, color = 'k')
ax1.text(245,5.2, "2" ,verticalalignment='center',color='k',weight='bold')
ax1.vlines(x=300, ymin=3.3, ymax=5.3, color = 'b')
ax1.text(305,5.2, "3" ,verticalalignment='center',color='k',weight='bold')
ax1.vlines(x=390, ymin=3.3, ymax=5.3, color = 'k')
ax1.text(395,5.2, "4" ,verticalalignment='center',color='k',weight='bold')

ax2 = ax1.twinx()
ax2.plot(time,Var_mean_north_ice,color='grey', linestyle='--',linewidth=3.0,label='ice fraction')
for tl in ax2.get_yticklabels():
    tl.set_color('grey') 
ax2.set_ylim(-0.005,0.09)
ax2.tick_params(axis = 'both', which = 'major', labelsize = 12)
ax1.tick_params(axis='both', top='off', labeltop='off')


ax2.set_ylabel('Arctic ice fraction', color='grey',fontsize='12')

#lines=ax1.get_lines()
#lines.extend(ax2.get_lines())
#labels=[l.get_label() for l in lines]
##plt.xlim(0,300)
#leg=ax1.legend(lines,labels,loc='lower left')   

fig.savefig('Modes_inplot.pdf', format='pdf',bbox_inches='tight') 



