#This script creates Fig.9 of 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'

# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
import numpy.ma as ma
from matplotlib.patches import Polygon
from matplotlib.pyplot import text


degree_sign= u'\N{DEGREE SIGN}'

oblname=['24p5']

y=np.array([779.67095947,992.65313721,1243.48986816,
            1532.65319824,1859.67089844,2223.1394043,2620.75683594,3049.38110352,
            3505.10644531])

x=np.array([60.,63.75,67.5,71.25,75.,78.75,82.5,86.25,90.])

xmid=np.array([61.875,65.625,69.375,73.125,76.875,80.625,84.375,88.125])
ymid=np.array([876.81634521,1108.48986816,1378.48986816,1686.81640625,2032.5255127,2413.75317383,2827.76049805,3271.00170898])  
                    
###############################################################################
#maximum Arctic overturning
newdata=np.loadtxt('ModelOutput_momh_24p5_3600s.dat')
newdata=newdata.reshape((3812,25,48))
newdata=np.ma.masked_equal(newdata,-1)
glbover_warmmode=newdata[2990,12:20,40:48] 
glbover_coldmode=newdata[3100,12:20,40:48]      
       
fg = plt.figure(figsize=(16,8))
adj = plt.subplots_adjust(hspace=0.3,wspace=0.3)

#exciting = np.load('exciting.npy').item()
cmap=plt.cm.rainbow

xgrid,ygrid=np.meshgrid(xmid,ymid)

sp1=plt.subplot(1,2,1)
cs =plt.pcolormesh(x,y,glbover_warmmode,vmin=-1.6,vmax=7,cmap=plt.cm.rainbow)
ct=plt.contour(xgrid,ygrid,glbover_warmmode,colors='k',linewidths=3)
plt.clabel(ct, inline=1, fontsize=12,fmt = '%1.0f')
sp1.set_title('(a)',x=-0.12,y=1.1,fontsize=14)
cmap.set_bad('k', 1.0)
plt.axis([60,90,780,3500])
sp1.tick_params(axis='both', which='major', labelsize=12)
plt.ylabel('depth (m)',fontsize=14)
plt.xlabel('latitude',fontsize=14)
plt.gca().invert_yaxis()
plt.gca().tick_params(direction='out')

sp2=plt.subplot(1,2,2)
cs =plt.pcolormesh(x,y,glbover_coldmode,vmin=-1.6,vmax=7,cmap=plt.cm.rainbow)
ct=plt.contour(xgrid,ygrid,glbover_coldmode,colors='k',linewidths=3)
plt.clabel(ct, inline=1, fontsize=12,fmt = '%1.0f')
sp2.set_title('(b)',x=-0.12,y=1.1,fontsize=14)
cmap.set_bad('k', 1.0)
plt.axis([60,90,780,3500])
sp2.tick_params(axis='both', which='major', labelsize=12)
plt.ylabel('depth (m)',fontsize=14)
plt.xlabel('latitude',fontsize=14)
plt.gca().invert_yaxis()
plt.gca().tick_params(direction='out')

plt.subplots_adjust(hspace=0.1)

#a=np.arange(-3,4)
#ticksbar=np.arange(-3,4,1)
cbar_ax = fg.add_axes([0.3, 0.002, 0.4, 0.015])
cbar=fg.colorbar(cs,cax=cbar_ax, orientation='horizontal') 
cbar.set_label('Arctic meridional overturning (Sv)',fontsize=14)
cbar_ax.tick_params(labelsize=12)                
fg.savefig('GLB_OVER.pdf', format='pdf',bbox_inches='tight') 



