#This script creates Fig. S2 in 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
import numpy.ma as ma
from matplotlib.patches import Polygon
#create other color map
import matplotlib.colors as colors
from matplotlib.mlab import bivariate_normal
import matplotlib.colors as cl

from gradient import createGradient

cmap_ferretrainbow = createGradient(cmap=plt.cm.hsv_r,   unit='rgba', start=0.2,  end=1,   limit=16, output=False)

colormap_ferretrainbow = cl.LinearSegmentedColormap.from_list("printMap", cmap_ferretrainbow)

cmaplist_rainbow = [colormap_ferretrainbow(i) for i in range(colormap_ferretrainbow.N)]

cmap = colormap_ferretrainbow.from_list('Custom cmap', cmaplist_rainbow, colormap_ferretrainbow.N)


degree_sign= u'\N{DEGREE SIGN}'

lonlatpsdata=np.loadtxt('ModelOutput_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]
lonmid=lonlatpsdata[66:82]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))

#MOM grid for ice and continental contours
lonlatmomdata=np.loadtxt('ModelOutput_smom_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[97:193]
lat0mom=lonlatmomdata[193:242]
latmidmom=lonlatmomdata[242:290]

pi_frac_mom=(np.pi/180)*latmidmom[:]

cont=[415,380,360]
contname=['415','380','360']

#cont=[360,380]
#contname=['360','380']

#number=['0202','0402','0602','0802','1002','1202','1402','1602','1802','2002','2202','2402','2602','2802','3002','3202','3402','3602','3802','4002']
   
namesp2h=np.array(['tsann'])       

Namevarlong=np.array(['surface air temperature, annual mean [°C]' ])

Var_mean=np.zeros((len(contname),len(namesp2h)))

#create grid for maps
#atmosphere borders
lon2d, lat2d = np.meshgrid(lon,lat)
x=lon2d
y=lat2d

#ocean centers
lon2dmom, lat2dmom = np.meshgrid(lonmidmom,latmidmom)
xmom=lon2dmom
ymom=lat2dmom

#ocean border
lon2dmom0, lat2dmom0 = np.meshgrid(lon0mom,lat0mom)
xmom0=lon2dmom0
ymom0=lat2dmom0

minvar=-1
maxvar=32

Varcont=np.zeros((3,24,16))
temp=np.zeros((3,48,96))
u=np.zeros((3,48,96))
v=np.zeros((3,48,96))


Cont=np.zeros((3,48,96))

for j in range(len(contname)):

    momdata=np.loadtxt('ModelOutput_momh_'+contname[j]+'_continents.dat')
    momdata=momdata.reshape((3,48,96))
    momdata=np.ma.masked_equal(momdata,-100)
    temp[j,:,:]=momdata[0,:,:] 
    temp=np.ma.masked_equal(temp,-100)
    u[j,:,:]=momdata[1,:,:] 
    u=np.ma.masked_equal(u,-100)
    v[j,:,:]=momdata[2,:,:] 
    v=np.ma.masked_equal(v,-100)
 

        
fig,axes = plt.subplots(nrows=3, ncols=1,figsize=(6,10))
ax1=axes[0]
ax2=axes[1]
ax3=axes[2]

ax=[ax1,ax2,ax3]    

fig.subplots_adjust(left=0., right=1., bottom=0.1, top=0.9,wspace=0.01,hspace=0.4)    
  

#########################################################################################################################
#415 Ma temp
m = Basemap(ax=ax1,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
            llcrnrlon=0, urcrnrlon=360, resolution='c')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    
ax1.set_ylabel('415 Ma',rotation=0, size='large',x=0,y=0.5, labelpad=60)
ax1.set_title('(a)',x=-0.2,y=1.0,fontsize=10)     

#temp
cs = m.pcolor(xmom0,ymom0,temp[0,:,:],latlon=True,cmap=colormap_ferretrainbow,vmin=-1,vmax=32)
m.quiver(xmom[::2,::3],ymom[::2,::3],u[0,::2,::3],v[0,::2,::3],latlon=True)#,scale=500,headlength=3,headaxislength=2)


#########################################################################################################################
#380 Ma temp
m = Basemap(ax=ax2,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
            llcrnrlon=0, urcrnrlon=360, resolution='c')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    
ax2.set_ylabel('380 Ma',rotation=0, size='large',x=0,y=0.5, labelpad=60)
ax2.set_title('(b)',x=-0.2,y=1.0,fontsize=10)     

#temp
cs = m.pcolor(xmom0,ymom0,temp[1,:,:],latlon=True,cmap=colormap_ferretrainbow,vmin=-1,vmax=32)
m.quiver(xmom[::2,::3],ymom[::2,::3],u[1,::2,::3],v[1,::2,::3],latlon=True)#,scale=500,headlength=3,headaxislength=2)


###########################################################################################################################
#360 Ma temp
m = Basemap(ax=ax3,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
            llcrnrlon=0, urcrnrlon=360, resolution='c')

m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[True,False,False,False],color='grey',fontsize=8)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,True],color='grey',fontsize=8)
    
ax3.set_ylabel('360 Ma',rotation=0, size='large',x=0,y=0.5, labelpad=60)
ax3.set_title('(c)',x=-0.2,y=1.0,fontsize=10)     

#temp
cs = m.pcolor(xmom0,ymom0,temp[2,:,:],latlon=True,cmap=colormap_ferretrainbow,vmin=-1,vmax=32)
Q=m.quiver(xmom[::2,::3],ymom[::2,::3],u[2,::2,::3],v[2,::2,::3],latlon=True)#,scale=500,headlength=3,headaxislength=2)
plt.quiverkey(Q,0.7,0.1,20,r'20 m/s', labelpos='E',
                   coordinates='figure')
###########################################################################################################################
#color bar
fig.subplots_adjust(bottom=0.15)
cbar_ax = fig.add_axes([0.2, 0.06, 0.6, 0.02])
cbar_ax.set_aspect('auto')

ticksbar=np.arange(-1,32,3)
ticksbar=np.append(ticksbar,33)

cbar=fig.colorbar(cs, cax=cbar_ax, orientation='horizontal',ticks=ticksbar,extend='both')            

cbar.set_label('Sea surface temperature ['+degree_sign+'C]',fontsize=10)
 
fig.savefig('Continents_maps_sstuv.eps', format='eps',bbox_inches='tight') 
