#This script creates Fig. 5 of the Supplementary Material for 'On the sensitivity of the Devonian climate to continental configuration, vegetation cover, orbital configuration, CO2 concentration and insolation'
# -*- coding: utf-8 -*-
"""
@author: juliabrugger
"""

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.legend as lgd
from mpl_toolkits.basemap import Basemap, addcyclic, shiftgrid
from scipy.interpolate import interp1d
from matplotlib.gridspec import GridSpec
from netCDF4 import Dataset
import sys
import numpy.ma as ma

np.set_printoptions(threshold=sys.maxint)


lonlatpsdata=np.loadtxt('ModelOutput_p2s_lonlat.dat')
lon=lonlatpsdata[0:17]
lat=lonlatpsdata[17:42]
latmid=lonlatpsdata[42:66]

pi_frac=(np.pi/180)*latmid[:]
weightsum=np.sum(np.cos(pi_frac))

lonlatmomdata=np.loadtxt('ModelOutput_smom_lonlat.dat')
lon0mom=lonlatmomdata[0:97]
lonmidmom=lonlatmomdata[97:193]
lat0mom=lonlatmomdata[193:242]
latmidmom=lonlatmomdata[242:290]

pi_frac_mom=(np.pi/180)*latmidmom[:]

#create grid for maps
lon2d, lat2d = np.meshgrid(lon, lat)
x=lon2d
y=lat2d

#############################################################################################################################
#1000 years data from snapshots
nc_f_bare_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_bare/history_p2.nc'
nc_f_shrub_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_shrubcover/history_p2.nc'
nc_f_tree_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_treecover/history_p2.nc'
nc_f_early_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_earlydevveg/history_p2.nc'
nc_f_middle_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_middledevveg/history_p2.nc'
nc_f_late_history = '/Volumes/IPLEX/p/projects/ace/brugger/c3beta_devn_380Ma_1500ppm_1319Wm2_O23p5_E0p000_P000_latedevveg/history_p2.nc'

historydata_bare = Dataset(nc_f_bare_history, 'r')
cld_bare=historydata_bare.variables['cld_ann'][5302:6302,:,:]
cld_bare=np.mean(cld_bare,axis=0)

historydata_shrub = Dataset(nc_f_shrub_history, 'r')
cld_shrub=historydata_shrub.variables['cld_ann'][4003:5003,:,:]
cld_shrub=np.mean(cld_shrub,axis=0)

historydata_tree = Dataset(nc_f_tree_history, 'r')
cld_tree=historydata_tree.variables['cld_ann'][4003:5003,:,:]
cld_tree=np.mean(cld_tree,axis=0)

historydata_early = Dataset(nc_f_early_history, 'r')
cld_early=historydata_early.variables['cld_ann'][4003:5003,:,:]
cld_early=np.mean(cld_early,axis=0)

historydata_middle = Dataset(nc_f_middle_history, 'r')
cld_middle=historydata_middle.variables['cld_ann'][4003:5003,:,:]
cld_middle=np.mean(cld_middle,axis=0)

historydata_late = Dataset(nc_f_late_history, 'r')
cld_late=historydata_late.variables['cld_ann'][4003:5003,:,:]
cld_late=np.mean(cld_late,axis=0)
####################################################################################################
cont380=np.loadtxt('ModelOutput_continents380.dat')
cont380=cont380.reshape((2,48,96))
cont380=cont380[0,:,:]#land ocean mask grid center
    #grid for continents
lon2dcont380, lat2dcont380 = np.meshgrid(lonmidmom, latmidmom)
xcont=lon2dcont380
ycont=lat2dcont380            
####################################################################################################
fig = plt.figure(figsize=(4,12))

gs=GridSpec(8,1,height_ratios=[1,1,0.1,0.1,1,1,1,0.1])

ax1=plt.subplot(gs[0])
ax2=plt.subplot(gs[1])
bar1=plt.subplot(gs[2])
bar1extra=plt.subplot(gs[3])
ax3=plt.subplot(gs[4])
ax4=plt.subplot(gs[5])
ax5=plt.subplot(gs[6])
bar2=plt.subplot(gs[7])

###############################################################################
plt.figtext(0.5,0.93,'Difference in cloud cover',fontsize=12, horizontalalignment='center')
plt.subplots_adjust(wspace=0.2, hspace=0.3)

###############################################################################
m = Basemap(ax=ax1,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs1 = m.pcolor(x,y,cld_shrub-cld_bare,latlon=True,cmap=plt.cm.bwr,vmin=-0.15,vmax=0.15) 
ax1.set_title('(a)',x=-0.2,y=0.5,fontsize=10)   
#ax13.set_ylabel(u'Shrub \u2212 Bare',rotation=0, fontsize=12,fontweight='semibold',y=0.4, labelpad=70)
m.contour(xcont,ycont,cont380,1,colors='k')  
###############################################################################
m = Basemap(ax=ax2,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs2= m.pcolor(x,y,cld_tree-cld_bare,latlon=True,cmap=plt.cm.bwr,vmin=-0.15,vmax=0.15) 
ax2.set_title('(b)',x=-0.2,y=0.5,fontsize=10)   
#ax17.set_ylabel(u'Tree \u2212 Bare',rotation=0, fontsize=12,fontweight='semibold',y=0.4, labelpad=70)
m.contour(xcont,ycont,cont380,1,colors='k')  
###############################################################################
###############################################################################
###############################################################################
cbar=plt.colorbar(cs1, cax=bar1, ticks=[-0.15,-0.1,0,0.1,0.15],orientation='horizontal',extend='both')            
#cbar.set_label('[$\degree$C]',fontsize=10)               
###############################################################################
###############################################################################
###############################################################################
bar1extra.axis('off')
###############################################################################
###############################################################################
###############################################################################
m = Basemap(ax=ax3,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)
            
cs3 = m.pcolor(x,y,cld_early-cld_bare,latlon=True,cmap=plt.cm.bwr,vmin=-0.07,vmax=0.07)      
ax3.set_title('(c)',x=-0.2,y=0.5,fontsize=10)
#ax1.set_ylabel(u'Early \u2212 Bare',rotation=0, fontsize=12,fontweight='semibold',y=0.4, labelpad=70)
#ax1.set_title('415 Ma',x=0.2,y=1.2,fontsize=10)
m.contour(xcont,ycont,cont380,1,colors='k')  
#cbar=fig.colorbar(cs, orientation='horizontal',extend='both')            
#cbar.set_label('elevation [m]',fontsize=12) 
############################################################################### 
m = Basemap(ax=ax4,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)
            
cs4 = m.pcolor(x,y,cld_middle-cld_bare,latlon=True,cmap=plt.cm.bwr,vmin=-0.07,vmax=0.07)      
ax4.set_title('(d)',x=-0.2,y=0.5,fontsize=10)
#ax5.set_ylabel(u'Middle \u2212 Bare',rotation=0, fontsize=12,fontweight='semibold',y=0.4, labelpad=70)
m.contour(xcont,ycont,cont380,1,colors='k')  
############################################################################### 
m = Basemap(ax=ax5,projection='cyl', llcrnrlat=-90, urcrnrlat=90,\
        llcrnrlon=0, urcrnrlon=360, resolution='c')
m.drawmapboundary()
m.drawparallels(np.arange(-90.,91.,30.),labels=[False,False,False, False],color='grey',fontsize=7)
m.drawmeridians(np.arange(-180.,181.,60),labels=[False,False,False,False],color='grey',fontsize=7)

cs5 = m.pcolor(x,y,cld_late-cld_bare,latlon=True,cmap=plt.cm.bwr,vmin=-0.07,vmax=0.07) 
ax5.set_title('(e)',x=-0.2,y=0.5,fontsize=10)   
#ax9.set_ylabel(u'Late \u2212 Bare',rotation=0, fontsize=12,fontweight='semibold',y=0.4, labelpad=70)
m.contour(xcont,ycont,cont380,1,colors='k')  
###############################################################################
###############################################################################
###############################################################################
cbar=plt.colorbar(cs5, cax=bar2, ticks=[-0.07,-0.03,0,0.03,0.07],orientation='horizontal',extend='both')            
#cbar.set_label('[$\degree$C]',fontsize=10)               


fig.savefig('Vegetation_Devoniantimes_clouds_1000years.pdf', format='pdf',bbox_inches='tight')    
